@@ -12,8 +12,7 @@ from launchable.utils.authentication import get_org_workspace
 from launchable.utils.session import parse_session
 
 from ..testpath import FilePathNormalizer, TestPath
-from ..utils.click import (DURATION, PERCENTAGE, DurationType, KeyValueType,
-                           PercentageType)
+from ..utils.click import DURATION, PERCENTAGE, DurationType, KeyValueType, PercentageType
 from ..utils.env_keys import REPORT_ERROR_KEY
 from ..utils.http_client import LaunchableClient
 from .helper import find_or_create_session
@@ -140,8 +139,10 @@ def subset(
 ):
 
     if is_observation and is_get_tests_from_previous_sessions:
-        click.echo(click.style(
-            "Cannot use --observation and --get-tests-from-previous-sessions options at the same time", fg="red"),
+        click.echo(
+            click.style(
+                "Cannot use --observation and --get-tests-from-previous-sessions options at the same time",
+                fg="red"),
             err=True,
         )
         sys.exit(1)
@@ -153,8 +154,7 @@ def subset(
         flavor=flavor,
         is_observation=is_observation,
     )
-    file_path_normalizer = FilePathNormalizer(
-        base_path, no_base_path_inference=no_base_path_inference)
+    file_path_normalizer = FilePathNormalizer(base_path, no_base_path_inference=no_base_path_inference)
 
     # TODO: placed here to minimize invasion in this PR to reduce the likelihood of
     # PR merge hell. This should be moved to a top-level class
@@ -170,7 +170,8 @@ def subset(
 
         # output_handler: Callable[[
         #   List[TestPathLike], List[TestPathLike]], None]
-        # exclusion_output_handler: Callable[[List[TestPathLike], List[TestPathLike], bool], None]]
+        # exclusion_output_handler: Callable[[List[TestPathLike],
+        # List[TestPathLike], bool], None]]
 
         def __init__(self, dry_run: bool = False):
             self.rest = rest
@@ -181,28 +182,13 @@ def subset(
             super(Optimize, self).__init__(dry_run=dry_run)
 
         def _default_output_handler(self, output: List[TestPath], rests: List[TestPath]):
-            # regardless of whether we managed to talk to the service we produce
-            # test names
             if rest:
-                if len(rests) == 0:
-                    rests.append(output[0])
-
                 self.write_file(rest, rests)
 
-            self.print(output)
+            if output:
+                self.print(output)
 
-        def _default_exclusion_output_handler(self, subset: List[TestPath], rest: List[TestPath], is_observation: bool):
-            # This requires third argument is_observation. During the
-            # observation mode, the subset is subset + rest and the rest is
-            # still rest. The reason that the rest won't be an empty array is
-            # not known. However, because the first version is written like so,
-            # we are not sure if changing this will break the users.
-            #
-            # For the custom implementations, when is_observation is True, they
-            # should assume that the 'true rest' is empty. Otherwise, it would
-            # produce bogus output.
-
-            # Swap here to make an inverse.
+        def _default_exclusion_output_handler(self, subset: List[TestPath], rest: List[TestPath]):
             self.output_handler(rest, subset)
 
         def test_path(self, path: TestPathLike):
@@ -215,8 +201,7 @@ def subset(
             if isinstance(path, str) and any(s in path for s in ('*', "?")):
                 for i in glob.iglob(path, recursive=True):
                     if os.path.isfile(i):
-                        self.test_paths.append(
-                            self.to_test_path(rel_base_path(i)))
+                        self.test_paths.append(self.to_test_path(rel_base_path(i)))
                 return
 
             """register one test"""
@@ -234,9 +219,12 @@ def subset(
             they didn't feed anything from stdin
             """
             if sys.stdin.isatty():
-                click.echo(click.style(
-                    "Warning: this command reads from stdin but it doesn't appear to be connected to anything. Did you forget to pipe from another command?",
-                    fg='yellow'), err=True)
+                click.echo(
+                    click.style(
+                        "Warning: this command reads from stdin but it doesn't appear to be connected to anything. "
+                        "Did you forget to pipe from another command?",
+                        fg='yellow'),
+                    err=True)
             return sys.stdin
 
         @staticmethod
@@ -264,7 +252,7 @@ def subset(
                 - if a TestPath is returned, that's added as is
             """
 
-            if path_builder == None:
+            if path_builder is None:
                 # default implementation of path_builder creates a file name relative to `source` so as not
                 # to be affected by the path
                 def default_path_builder(file_name):
@@ -319,36 +307,34 @@ def subset(
             """called after tests are scanned to compute the optimized order"""
 
             # When Error occurs, return the test name as it is passed.
-            output = self.test_paths
-            rests = []
+            original_subset = self.test_paths
+            original_rests = []
             summary = {}
             subset_id = ""
             is_brainless = False
             is_observation = False
 
             if not session_id:
-                # Session ID in --session is missing. It might be caused by Launchable API errors.
+                # Session ID in --session is missing. It might be caused by
+                # Launchable API errors.
                 pass
             else:
                 try:
                     test_runner = context.invoked_subcommand
-                    client = LaunchableClient(
-                        test_runner=test_runner,
-                        dry_run=context.obj.dry_run)
+                    client = LaunchableClient(test_runner=test_runner, dry_run=context.obj.dry_run)
 
                     # temporarily extend the timeout because subset API response has become slow
-                    # TODO: remove this line when API response return respose within 60 sec
+                    # TODO: remove this line when API response return respose
+                    # within 60 sec
                     timeout = (5, 180)
-                    payload = self.get_payload(
-                        session_id, target, duration, test_runner)
+                    payload = self.get_payload(session_id, target, duration, test_runner)
 
-                    res = client.request(
-                        "post", "subset", timeout=timeout, payload=payload, compress=True)
+                    res = client.request("post", "subset", timeout=timeout, payload=payload, compress=True)
 
                     res.raise_for_status()
 
-                    output = res.json()["testPaths"]
-                    rests = res.json()["rest"]
+                    original_subset = res.json().get("testPaths", [])
+                    original_rests = res.json().get("rest", [])
                     subset_id = res.json()["subsettingId"]
                     summary = res.json()["summary"]
                     is_brainless = res.json().get("isBrainless", False)
@@ -363,26 +349,26 @@ def subset(
                         "Warning: the service failed to subset. Falling back to running all tests", fg='yellow'),
                         err=True)
 
-            if len(output) == 0:
-                click.echo(click.style(
-                    "Error: no tests found matching the path.", 'yellow'), err=True)
+            if len(original_subset) == 0:
+                click.echo(click.style("Error: no tests found matching the path.", 'yellow'), err=True)
                 return
 
             if split:
                 click.echo("subset/{}".format(subset_id))
             else:
-                _output, _rests = output, rests
+                output_subset, output_rests = original_subset, original_rests
 
                 if is_observation:
-                    _output = _output + _rests
+                    output_subset = output_subset + output_rests
+                    output_rests = []
 
                 if is_output_exclusion_rules:
-                    self.exclusion_output_handler(
-                        _output, _rests, is_observation)
+                    self.exclusion_output_handler(output_subset, output_rests)
                 else:
-                    self.output_handler(_output, _rests)
+                    self.output_handler(output_subset, output_rests)
 
-            # When Launchable returns an error, the cli skips showing summary report
+            # When Launchable returns an error, the cli skips showing summary
+            # report
             if "subset" not in summary.keys() or "rest" not in summary.keys():
                 return
 
@@ -394,24 +380,22 @@ def subset(
             rows = [
                 [
                     "Subset",
-                    len(output),
+                    len(original_subset),
                     summary["subset"].get("rate", 0.0),
                     summary["subset"].get("duration", 0.0),
                 ],
                 [
                     "Remainder",
-                    len(rests),
+                    len(original_rests),
                     summary["rest"].get("rate", 0.0),
                     summary["rest"].get("duration", 0.0),
                 ],
                 [],
                 [
                     "Total",
-                    len(output) + len(rests),
-                    summary["subset"].get("rate", 0.0) +
-                    summary["rest"].get("rate", 0.0),
-                    summary["subset"].get("duration", 0.0) +
-                    summary["rest"].get("duration", 0.0),
+                    len(original_subset) + len(original_rests),
+                    summary["subset"].get("rate", 0.0) + summary["rest"].get("rate", 0.0),
+                    summary["subset"].get("duration", 0.0) + summary["rest"].get("duration", 0.0),
                 ],
             ]
 
@@ -428,12 +412,15 @@ def subset(
                 ), err=True,
             )
             if is_observation:
-                click.echo("(This test session is under observation mode)", err=True)
+                click.echo(
+                    "(This test session is under observation mode)",
+                    err=True)
 
             click.echo("", err=True)
             click.echo(tabulate(rows, header, tablefmt="github"), err=True)
 
             click.echo(
-                "\nRun `launchable inspect subset --subset-id {}` to view full subset details".format(subset_id), err=True)
+                "\nRun `launchable inspect subset --subset-id {}` to view full subset details".format(subset_id),
+                err=True)
 
     context.obj = Optimize(dry_run=context.obj.dry_run)
