@@ -6,9 +6,9 @@ import tempfile
 import types
 import unittest
 
-import click.testing
+import click  # type: ignore
 import responses  # type: ignore
-from click.testing import CliRunner
+from click.testing import CliRunner  # type: ignore
 
 from launchable.__main__ import main
 from launchable.utils.http_client import get_base_url
@@ -21,8 +21,7 @@ class CliTestCase(unittest.TestCase):
     """
     organization = 'launchableinc'
     workspace = 'mothership'
-    launchable_token = "v1:{}/{}:auth-token-sample".format(
-        organization, workspace)
+    launchable_token = "v1:{}/{}:auth-token-sample".format(organization, workspace)
     session_id = 16
     build_name = "123"
     subsetting_id = 456
