@@ -6,13 +6,13 @@ from pathlib import Path
 from unittest import mock
 
 import responses  # type: ignore
+
 from launchable.utils.session import read_session, write_build
 from tests.cli_test_case import CliTestCase
 
 
 class BazelTest(CliTestCase):
-    test_files_dir = Path(__file__).parent.joinpath(
-        '../data/bazel/').resolve()
+    test_files_dir = Path(__file__).parent.joinpath('../data/bazel/').resolve()
     subset_input = """Starting local Bazel server and connecting to it...
 //src/test/java/com/ninjinkun:mylib_test9
 //src/test/java/com/ninjinkun:mylib_test8
@@ -32,15 +32,12 @@ Loading: 2 packages loaded
         # emulate launchable record build
         write_build(self.build_name)
 
-        result = self.cli('subset', '--target', '10%',
-                          'bazel', input=self.subset_input)
+        result = self.cli('subset', '--target', '10%', 'bazel', input=self.subset_input)
         self.assertEqual(result.exit_code, 0)
         self.assertEqual(read_session(self.build_name), self.session)
 
-        payload = json.loads(gzip.decompress(
-            responses.calls[1].request.body).decode())
-        expected = self.load_json_from_file(
-            self.test_files_dir.joinpath('subset_result.json'))
+        payload = json.loads(gzip.decompress(responses.calls[1].request.body).decode())
+        expected = self.load_json_from_file(self.test_files_dir.joinpath('subset_result.json'))
         self.assert_json_orderless_equal(payload, expected)
 
     @responses.activate
@@ -49,15 +46,12 @@ Loading: 2 packages loaded
         # emulate launchable record build
         write_build(self.build_name)
 
-        result = self.cli('record', 'tests', 'bazel',
-                          str(self.test_files_dir) + "/")
+        result = self.cli('record', 'tests', 'bazel', str(self.test_files_dir) + "/")
         self.assertEqual(result.exit_code, 0)
         self.assertEqual(read_session(self.build_name), self.session)
 
-        payload = json.loads(gzip.decompress(
-            responses.calls[2].request.body).decode())
-        expected = self.load_json_from_file(
-            self.test_files_dir.joinpath('record_test_result.json'))
+        payload = json.loads(gzip.decompress(responses.calls[2].request.body).decode())
+        expected = self.load_json_from_file(self.test_files_dir.joinpath('record_test_result.json'))
 
         for c in payload['events']:
             del c['created_at']
@@ -75,10 +69,8 @@ Loading: 2 packages loaded
         self.assertEqual(result.exit_code, 0)
         self.assertEqual(read_session(self.build_name), self.session)
 
-        payload = json.loads(gzip.decompress(
-            responses.calls[2].request.body).decode())
-        expected = self.load_json_from_file(
-            self.test_files_dir.joinpath('record_test_with_build_event_json_result.json'))
+        payload = json.loads(gzip.decompress(responses.calls[2].request.body).decode())
+        expected = self.load_json_from_file(self.test_files_dir.joinpath('record_test_with_build_event_json_result.json'))
 
         for c in payload['events']:
             del c['created_at']
@@ -91,15 +83,16 @@ Loading: 2 packages loaded
         # emulate launchable record build
         write_build(self.build_name)
 
-        result = self.cli('record', 'tests', 'bazel', '--build-event-json', str(self.test_files_dir.joinpath("build_event.json")),
-                          '--build-event-json', str(self.test_files_dir.joinpath("build_event_rest.json")), str(self.test_files_dir) + "/")
+        result = self.cli('record', 'tests', 'bazel', '--build-event-json',
+                          str(self.test_files_dir.joinpath("build_event.json")),
+                          '--build-event-json', str(self.test_files_dir.joinpath("build_event_rest.json")),
+                          str(self.test_files_dir) + "/")
         self.assertEqual(result.exit_code, 0)
         self.assertEqual(read_session(self.build_name), self.session)
 
-        payload = json.loads(gzip.decompress(
-            responses.calls[2].request.body).decode())
-        expected = self.load_json_from_file(
-            self.test_files_dir.joinpath('record_test_with_multiple_build_event_json_result.json'))
+        payload = json.loads(gzip.decompress(responses.calls[2].request.body).decode())
+        expected = self.load_json_from_file(self.test_files_dir.joinpath(
+            'record_test_with_multiple_build_event_json_result.json'))
 
         for c in payload['events']:
             del c['created_at']
@@ -115,28 +108,21 @@ Loading: 2 packages loaded
         """
         Test recorded test results contain subset's test path
         """
-        result = self.cli('subset', '--target', '10%',
-                          'bazel', input=self.subset_input)
+        result = self.cli('subset', '--target', '10%', 'bazel', input=self.subset_input)
 
         self.assertEqual(result.exit_code, 0)
 
-        subset_payload = json.loads(gzip.decompress(
-            responses.calls[1].request.body).decode())
+        subset_payload = json.loads(gzip.decompress(responses.calls[1].request.body).decode())
 
-        result = self.cli('record', 'tests', 'bazel',
-                          str(self.test_files_dir) + "/")
+        result = self.cli('record', 'tests', 'bazel', str(self.test_files_dir) + "/")
         self.assertEqual(result.exit_code, 0)
 
-        record_payload = json.loads(gzip.decompress(
-            responses.calls[3].request.body).decode())
+        record_payload = json.loads(gzip.decompress(responses.calls[3].request.body).decode())
 
-        record_test_paths = itertools.chain.from_iterable(
-            e['testPath'] for e in record_payload['events'])
+        record_test_paths = itertools.chain.from_iterable(e['testPath'] for e in record_payload['events'])
         record_test_path_dict = {t['name']: t for t in record_test_paths}
 
         for test_paths in subset_payload['testPaths']:
             for subset_test_path in test_paths:
-                record_test_path = record_test_path_dict.get(
-                    subset_test_path['name'])
-                self.assert_json_orderless_equal(
-                    record_test_path, subset_test_path)
+                record_test_path = record_test_path_dict.get(subset_test_path['name'])
+                self.assert_json_orderless_equal(record_test_path, subset_test_path)
